@@ -5,8 +5,8 @@
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
 ;; Maintainer: Joost Kremers <joostkremers@fastmail.fm>
 ;; Created: 31 Oct 2009
-;; Package-Version: 20251024.2344
-;; Package-Revision: da577c6f5ac0
+;; Package-Version: 20251029.1925
+;; Package-Revision: 8d6e976b465c
 ;; Keywords: text, pandoc
 ;; URL: http://joostkremers.github.io/pandoc-mode/
 
@@ -892,7 +892,7 @@ file exists, display the *Pandoc output* buffer."
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (defun pandoc--read-completion-function (formats)
-  "Create a completion function for `pandoc-set-read' for FORMATS.
+  "Create a completion function for `pandoc-set-read-from-category' for FORMATS.
 Return a function that can be used in `completing-read' as the
 COLLECTION function, using TABLE as the completion table."
   (lambda (str pred flag)
@@ -904,7 +904,7 @@ COLLECTION function, using TABLE as the completion table."
                                                          'face 'italic))))
       (complete-with-action flag formats str pred))))
 
-(defun pandoc-set-read (category)
+(defun pandoc-set-read-from-category (category)
   "Set the input format.
 CATEGORY is a string naming a category of formats as listed in
 `pandoc--formats'.  Only formats from CATEGORY are offered as completion
@@ -914,6 +914,14 @@ candidates."
     (pandoc--set 'read format)
     (message "Input format set to `%s'" format)))
 
+(defun pandoc-set-read (format)
+  "Set the input format to FORMAT."
+  (interactive (list (completing-read "Set input format to: "
+                                      (pandoc--extract-formats 'input)
+                                      nil t)))
+  (pandoc--set 'read format)
+  (message "Input format set to `%s'" format))
+
 (defun pandoc-set-write (format)
   "Set the output format to FORMAT.
 If a settings and/or project file exists for FORMAT, they are
@@ -1183,10 +1191,10 @@ argument, the option is toggled."
     ("o" "Options"               pandoc-options-transient)
     ("I" pandoc-input-formats-transient
      :description (lambda ()
-                    (format "Input format [%s]" (propertize (pandoc--get 'read) 'face 'warning))))
+                    (format "Input format [%s]" (propertize (or (pandoc--get 'read) "none") 'face 'warning))))
     ("O" pandoc-output-formats-transient
      :description (lambda ()
-                    (format "Output format [%s]" (propertize (pandoc--get 'write) 'face 'warning))))
+                    (format "Output format [%s]" (propertize (or (pandoc--get 'write) "none") 'face 'warning))))
     ("s" "Settings files"        pandoc-settings-file-transient)
     ("e" "Example lists"         pandoc-@-transient)]]
   [("q" "Quit" transient-quit-all)])
@@ -1258,7 +1266,8 @@ argument, the option is toggled."
                                                         (key (nth 2 format-spec)))
                                                     (list key description (lambda ()
                                                                             (interactive)
-                                                                            (pandoc-set-read format-name)))))
+                                                                            (pandoc-set-read format-name))
+                                                          :transient t)))
                                                (seq-filter (lambda (elt)
                                                              (not (eq (nth 3 elt) 'output)))
                                                            (drop 3 (quote ,group))))
@@ -1286,7 +1295,8 @@ argument, the option is toggled."
                                                         (key (nth 2 format-spec)))
                                                     (list key description (lambda ()
                                                                             (interactive)
-                                                                            (pandoc-set-write format-name)))))
+                                                                            (pandoc-set-write format-name))
+                                                          :transient t)))
                                                (seq-filter (lambda (elt)
                                                              (not (eq (nth 3 elt) 'input)))
                                                            (drop 3 (quote ,group))))
